@@ -1,13 +1,6 @@
 #ifndef CONFIG_H
 #define CONFIG_H
 
-// Apparently some Curses implementations don't support italic text
-#ifdef A_ITALIC
-#define NEWSRAFT_ITALIC A_ITALIC
-#else
-#define NEWSRAFT_ITALIC A_NORMAL
-#endif
-
 typedef uint8_t config_type_id;
 enum config_type {
 	CFG_BOOL,
@@ -17,9 +10,9 @@ enum config_type {
 };
 
 struct config_color {
-	int fg;
-	int bg;
-	unsigned int attributes;
+	uintattr_t fg;
+	uintattr_t bg;
+	uintattr_t attributes;
 };
 
 struct config_string {
@@ -62,24 +55,25 @@ static struct config_entry config[] = {
 
 #endif // CONFIG_ARRAY
 
-CFG(CFG_COLOR_STATUS,                    "color-status",                    CFG_COLOR,  {.c = {COLOR_GREEN,   -1, A_BOLD}})
-CFG(CFG_COLOR_STATUS_INFO,               "color-status-info",               CFG_COLOR,  {.c = {COLOR_CYAN,    -1, A_BOLD}})
-CFG(CFG_COLOR_STATUS_FAIL,               "color-status-fail",               CFG_COLOR,  {.c = {COLOR_RED,     -1, A_BOLD}})
-CFG(CFG_COLOR_LIST_ITEM,                 "color-list-item",                 CFG_COLOR,  {.c = {-1,            -1, A_NORMAL}})
-CFG(CFG_COLOR_LIST_ITEM_UNREAD,          "color-list-item-unread",          CFG_COLOR,  {.c = {COLOR_YELLOW,  -1, A_NORMAL}})
-CFG(CFG_COLOR_LIST_ITEM_IMPORTANT,       "color-list-item-important",       CFG_COLOR,  {.c = {COLOR_MAGENTA, -1, A_NORMAL}})
-CFG(CFG_COLOR_LIST_FEED,                 "color-list-feed",                 CFG_COLOR,  {.c = {-1,            -1, A_NORMAL}})
-CFG(CFG_COLOR_LIST_FEED_UNREAD,          "color-list-feed-unread",          CFG_COLOR,  {.c = {COLOR_YELLOW,  -1, A_NORMAL}})
-CFG(CFG_COLOR_LIST_FEED_FAILED,          "color-list-feed-failed",          CFG_COLOR,  {.c = {COLOR_RED,     -1, A_NORMAL}})
-CFG(CFG_COLOR_LIST_SECTION,              "color-list-section",              CFG_COLOR,  {.c = {-1,            -1, A_NORMAL}})
-CFG(CFG_COLOR_LIST_SECTION_UNREAD,       "color-list-section-unread",       CFG_COLOR,  {.c = {COLOR_YELLOW,  -1, A_NORMAL}})
-CFG(CFG_COLOR_LIST_SECTION_FAILED,       "color-list-section-failed",       CFG_COLOR,  {.c = {COLOR_RED,     -1, A_NORMAL}})
+CFG(CFG_COLOR_STATUS,                    "color-status",                    CFG_COLOR,  {.c = {TB_GREEN,   TB_DEFAULT, TB_BOLD}})
+CFG(CFG_COLOR_STATUS_INFO,               "color-status-info",               CFG_COLOR,  {.c = {TB_CYAN,    TB_DEFAULT, TB_BOLD}})
+CFG(CFG_COLOR_STATUS_FAIL,               "color-status-fail",               CFG_COLOR,  {.c = {TB_RED,     TB_DEFAULT, TB_BOLD}})
+CFG(CFG_COLOR_LIST_ITEM,                 "color-list-item",                 CFG_COLOR,  {.c = {TB_DEFAULT, TB_DEFAULT, TB_DEFAULT}})
+CFG(CFG_COLOR_LIST_ITEM_UNREAD,          "color-list-item-unread",          CFG_COLOR,  {.c = {TB_YELLOW,  TB_DEFAULT, TB_DEFAULT}})
+CFG(CFG_COLOR_LIST_ITEM_IMPORTANT,       "color-list-item-important",       CFG_COLOR,  {.c = {TB_MAGENTA, TB_DEFAULT, TB_DEFAULT}})
+CFG(CFG_COLOR_LIST_FEED,                 "color-list-feed",                 CFG_COLOR,  {.c = {TB_DEFAULT, TB_DEFAULT, TB_DEFAULT}})
+CFG(CFG_COLOR_LIST_FEED_UNREAD,          "color-list-feed-unread",          CFG_COLOR,  {.c = {TB_YELLOW,  TB_DEFAULT, TB_DEFAULT}})
+CFG(CFG_COLOR_LIST_FEED_FAILED,          "color-list-feed-failed",          CFG_COLOR,  {.c = {TB_RED,     TB_DEFAULT, TB_DEFAULT}})
+CFG(CFG_COLOR_LIST_SECTION,              "color-list-section",              CFG_COLOR,  {.c = {TB_DEFAULT, TB_DEFAULT, TB_DEFAULT}})
+CFG(CFG_COLOR_LIST_SECTION_UNREAD,       "color-list-section-unread",       CFG_COLOR,  {.c = {TB_YELLOW,  TB_DEFAULT, TB_DEFAULT}})
+CFG(CFG_COLOR_LIST_SECTION_FAILED,       "color-list-section-failed",       CFG_COLOR,  {.c = {TB_RED,     TB_DEFAULT, TB_DEFAULT}})
 CFG(CFG_RELOAD_PERIOD,                   "reload-period",                   CFG_UINT,   {.u = 0   })
 CFG(CFG_ITEM_LIMIT,                      "item-limit",                      CFG_UINT,   {.u = 0   })
 CFG(CFG_SCROLLOFF,                       "scrolloff",                       CFG_UINT,   {.u = 0   })
 CFG(CFG_PAGER_WIDTH,                     "pager-width",                     CFG_UINT,   {.u = 100 })
 CFG(CFG_DOWNLOAD_TIMEOUT,                "download-timeout",                CFG_UINT,   {.u = 20  })
 CFG(CFG_DOWNLOAD_SPEED_LIMIT,            "download-speed-limit",            CFG_UINT,   {.u = 0   })
+CFG(CFG_DOWNLOAD_MAX_CONNECTIONS,        "download-max-connections",        CFG_UINT,   {.u = 500 })
 CFG(CFG_DOWNLOAD_MAX_HOST_CONNECTIONS,   "download-max-host-connections",   CFG_UINT,   {.u = 0   })
 CFG(CFG_STATUS_PLACEHOLDER,              "status-placeholder",              CFG_STRING, {.s = {.base = "r:reload  R:reload-all  tab:explore  d:read  D:unread  f:important  F:unimportant  n:next-unread  N:prev-unread  p:next-important  P:prev-important"}})
 CFG(CFG_COPY_TO_CLIPBOARD_COMMAND,       "copy-to-clipboard-command",       CFG_STRING, {.s = {.base = "auto", .auto_set = &obtain_clipboard_command}})
@@ -93,7 +87,7 @@ CFG(CFG_ITEM_CONTENT_FORMAT,             "item-content-format",             CFG_
 CFG(CFG_ITEM_CONTENT_DATE_FORMAT,        "item-content-date-format",        CFG_STRING, {.s = {.base = "%a, %d %b %Y %H:%M:%S %z"}})
 CFG(CFG_ITEM_CONTENT_LINK_FORMAT,        "item-content-link-format",        CFG_STRING, {.s = {.base = "<b>[%i]</b>:&nbsp;%l<br>"}})
 CFG(CFG_LIST_ENTRY_DATE_FORMAT,          "list-entry-date-format",          CFG_STRING, {.s = {.base = "%b %d"}})
-CFG(CFG_OPEN_IN_BROWSER_COMMAND,         "open-in-browser-command",         CFG_STRING, {.s = {.base = "${BROWSER:-xdg-open} \"%l\""}})
+CFG(CFG_OPEN_IN_BROWSER_COMMAND,         "open-in-browser-command",         CFG_STRING, {.s = {.base = "auto", .auto_set = &obtain_browser_command}})
 CFG(CFG_NOTIFICATION_COMMAND,            "notification-command",            CFG_STRING, {.s = {.base = "auto", .auto_set = &obtain_notification_command}})
 CFG(CFG_MENU_SECTION_ENTRY_FORMAT,       "menu-section-entry-format",       CFG_STRING, {.s = {.base = "%5.0u @ %t"}})
 CFG(CFG_MENU_FEED_ENTRY_FORMAT,          "menu-feed-entry-format",          CFG_STRING, {.s = {.base = "%5.0u │ %t"}})
@@ -119,6 +113,7 @@ CFG(CFG_RESPECT_EXPIRES_HEADER,          "respect-expires-header",          CFG_
 CFG(CFG_SEND_IF_NONE_MATCH_HEADER,       "send-if-none-match-header",       CFG_BOOL,   {.b = true })
 CFG(CFG_SEND_IF_MODIFIED_SINCE_HEADER,   "send-if-modified-since-header",   CFG_BOOL,   {.b = true })
 CFG(CFG_PAGER_CENTERING,                 "pager-centering",                 CFG_BOOL,   {.b = true })
+CFG(CFG_IGNORE_NO_COLOR,                 "ignore-no-color",                 CFG_BOOL,   {.b = false})
 CFG(CFG_ENTRIES_COUNT,                   NULL,                              CFG_BOOL,   {.b = false})
 
 #ifdef CFG
