@@ -29,20 +29,19 @@ update_status_window_content_unprotected(void)
 	// appear in the window. The solution to this is wclear, but it makes
 	// screen flicker on the old hardware.
 	werase(status_window);
-	wmove(status_window, 0, 0);
+	wmove(status_window, 0);
 
 	if (they_want_us_to_stop == true) {
-		wbkgd(status_window, get_cfg_color(NULL, CFG_COLOR_STATUS_FAIL));
 		waddnstr(status_window, "Terminating...", list_menu_width);
+		wbkgd(status_window, get_cfg_color(NULL, CFG_COLOR_STATUS_FAIL));
 	} else if (search_mode_is_enabled == true) {
-		wbkgd(status_window, get_cfg_color(NULL, CFG_COLOR_STATUS));
 		waddwstr(status_window, L"/");
 		waddwstr(status_window, search_mode_text_input->ptr);
-	} else if (!STRING_IS_EMPTY(message_text)) {
-		wbkgd(status_window, get_cfg_color(NULL, message_color));
-		waddnstr(status_window, message_text->ptr, list_menu_width);
-	} else {
 		wbkgd(status_window, get_cfg_color(NULL, CFG_COLOR_STATUS));
+	} else if (!STRING_IS_EMPTY(message_text)) {
+		waddnstr(status_window, message_text->ptr, list_menu_width);
+		wbkgd(status_window, get_cfg_color(NULL, message_color));
+	} else {
 		struct string *path = NULL;
 		if (get_cfg_bool(NULL, CFG_STATUS_SHOW_MENU_PATH)) {
 			path = crtes(100);
@@ -53,17 +52,18 @@ update_status_window_content_unprotected(void)
 		} else {
 			waddnstr(status_window, get_cfg_string(NULL, CFG_STATUS_PLACEHOLDER)->ptr, list_menu_width);
 		}
+		wbkgd(status_window, get_cfg_color(NULL, CFG_COLOR_STATUS));
 		free_string(path);
 	}
 
 	// Print count value
-	wmove(status_window, 0, list_menu_width - 11);
+	wmove(status_window, list_menu_width - 11);
 	if (count_buf_len > 0) {
 		waddstr(status_window, "  "); // Little divider to separate from previous stuff
 		waddnstr(status_window, count_buf, count_buf_len);
 	}
 
-	wrefresh(status_window);
+	tb_present();
 }
 
 static void
@@ -80,20 +80,8 @@ status_recreate_unprotected(void)
 	if (status_window != NULL) {
 		delwin(status_window);
 	}
-
-	status_window = newwin(1, list_menu_width, list_menu_height, 0);
-	if (status_window == NULL) {
-		write_error("Failed to create status window!\n");
-		return false;
-	}
-
+	status_window = newwin(list_menu_height);
 	INFO("Created status window");
-
-	nodelay(status_window, TRUE);
-	if (keypad(status_window, TRUE) == ERR) {
-		WARN("Can't enable keypad and function keys reading support for status window!");
-	}
-
 	status_window_is_initialized = true;
 	update_status_window_content_unprotected();
 	return true;
@@ -168,10 +156,10 @@ status_delete(void)
 input_id
 get_input(struct input_binding *ctx, uint32_t *count, const struct wstring **p_arg)
 {
-	static wint_t c = 0;
+	static char key[1000];
 	static size_t queued_action_index = 0;
 	if (queued_action_index > 0) {
-		input_id next = get_action_of_bind(ctx, keyname(c), queued_action_index, p_arg);
+		input_id next = get_action_of_bind(ctx, key, queued_action_index, p_arg);
 		if (next != INPUT_ERROR) {
 			queued_action_index += 1;
 			return next;
@@ -184,26 +172,25 @@ get_input(struct input_binding *ctx, uint32_t *count, const struct wstring **p_a
 		// reading it from the main window will bring stdscr
 		// on top of other windows and overlap them.
 		pthread_mutex_lock(&interface_lock);
-		int status = wget_wch(status_window, &c);
+		int status = get_wch(key);
 		pthread_mutex_unlock(&interface_lock);
-		if (status == ERR) {
+		if (status == TB_ERR) {
 			if (they_want_us_to_break_input == true) {
 				they_want_us_to_break_input = false;
 				return INPUT_ERROR;
 			}
 			nanosleep(&input_polling_period, NULL);
 			continue;
-		} else if (c == KEY_RESIZE) {
+		} else if (status == TB_EVENT_RESIZE) {
 			return resize_handler();
 		}
-		const char *key = keyname(c);
-		INFO("Read key %d (\'%lc\', \"%s\")", c, c, key ? key : "ERROR");
+		INFO("Read key: %s", key);
 		if (search_mode_is_enabled == true) {
-			if (c == '\n' || c == 27) {
+			if (strcmp(key, "enter") == 0 || strcmp(key, "escape") == 0) {
 				search_mode_is_enabled = false;
 				status_clean();
-				if (c == '\n') return INPUT_APPLY_SEARCH_MODE_FILTER;
-			} else if (c == KEY_BACKSPACE || c == KEY_DC || c == 127) {
+				if (strcmp(key, "enter") == 0) return INPUT_APPLY_SEARCH_MODE_FILTER;
+			} else if (strcmp(key, "backspace") == 0) {
 				if (search_mode_text_input->len > 0) {
 					search_mode_text_input->len -= 1;
 					search_mode_text_input->ptr[search_mode_text_input->len] = L'\0';
@@ -213,12 +200,14 @@ get_input(struct input_binding *ctx, uint32_t *count, const struct wstring **p_a
 					status_clean();
 				}
 			} else {
-				wcatcs(search_mode_text_input, c);
+				struct wstring *wkey = convert_array_to_wstring(key, strlen(key));
+				wcatss(search_mode_text_input, wkey);
+				free_wstring(wkey);
 				update_status_window_content();
 			}
-		} else if (ISDIGIT(c)) {
+		} else if (ISDIGIT(key[0])) {
 			count_buf_len %= 9;
-			count_buf[count_buf_len++] = c;
+			count_buf[count_buf_len++] = key[0];
 			update_status_window_content();
 		} else {
 			input_id cmd = get_action_of_bind(ctx, key, 0, p_arg);
