@@ -41,7 +41,7 @@ get_item_args(struct menu_state *ctx, size_t index)
 	return item_fmt;
 }
 
-static unsigned
+static struct config_color
 paint_item(struct menu_state *ctx, size_t index)
 {
 	struct config_context **cfg = &ctx->items->ptr[index].feed[0]->cfg;
@@ -203,6 +203,8 @@ items_menu_loop(struct menu_state *m)
 				run_formatted_command(browser, get_item_args(m, m->view_sel));
 				break;
 			case INPUT_SORT_BY_TIME:
+			case INPUT_SORT_BY_TIME_UPDATE:
+			case INPUT_SORT_BY_TIME_PUBLICATION:
 			case INPUT_SORT_BY_ROWID:
 			case INPUT_SORT_BY_UNREAD:
 			case INPUT_SORT_BY_ALPHABET:
